# Arfin-Renderer-PyPi-Package


This repository contains the source code and documentation for the Arfin Renderer Python package, which is available on PyPi. 

## How to run?

# Installation:

# Create a conda environment

```bash
conda create -n arfinrenderer python=3.8 -y
```

```bash
conda activate Arfinrenderer
```

```bash
pip install -r requirements_dev.txt
```


